# `molecule-qemu`

Molecule QEMU driver for testing Ansible roles.

# Reference

* [Ansible](https://www.ansible.com/)
* [Molecule](https://molecule.readthedocs.io/en/latest/)
* [QEMU](https://www.qemu.org/)
